import 'dart:async';
import 'package:flutter/material.dart';
import 'widgets/map_widget.dart';
import 'marker_handler/marker_data.dart';
import 'consts.dart';
import 'marker_handler/get_markers.dart';

class DefaultPage extends StatefulWidget {
  const DefaultPage({super.key});

  @override
  _DefaultPageState createState() => _DefaultPageState();
}

class _DefaultPageState extends State<DefaultPage> {
  late Timer _timer;
  bool showBar = false;

  List<Measurement> markerList = [];

  // Call fetchMarkerTemplate and await its result before setting the state
  Future<void> loadMarkerList() async {
    try {
      List<Measurement> fetchedMarkers = await fetchMarkerData();

      setState(() {
        markerList = fetchedMarkers;
      });
    } catch (e) {
      showDialog(
        context: context,
        builder: (BuildContext context) {
          return AlertDialog(
            title: const Text("Error"),
            content: Text(e.toString()),
            actions: [
              TextButton(
                onPressed: () {
                  Navigator.of(context).pop();
                },
                child: const Text("OK"),
              ),
            ],
          );
        },
      );
    }
  }

  // State initializer
  @override
  void initState() {
    super.initState();
    // Load marker data from server
    loadMarkerList();

    // Schedule fetchMarkerData to run periodically based on fetchInterval from consts
    const Duration interval = Duration(minutes: fetchInterval);
    _timer = Timer.periodic(interval, (timer) {
      fetchMarkerData();
    });
  }

  // Fetch timer
  @override
  void dispose() {
    // Cancel timer on widget termination
    _timer.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Container(
        decoration: const BoxDecoration( // Set background color
          gradient: LinearGradient(
            begin: Alignment.topCenter,
            end: Alignment.bottomCenter,
            colors: [darkBlue, darkestBlue],
          ),
        ),
        child: Scaffold(
          backgroundColor: Colors.transparent,
          appBar: AppBar(
            title: const Text('IceMap'),
            actions: [
              IconButton(
                icon: const Icon(Icons.search),
                onPressed: () {
                  showBar = !showBar;
                },
              ),
            ],
          ),
          body: ListView(
            children: [ // Add main widget
              MapContainerWidget(markerList: markerList),
            ],
          ),
        ),
      ),
    );
  }
}